import { request } from 'umi';
// import { stringify } from 'qs';

export async function queryRes(params) {
  return request(`/res`, { params });
}
export async function queryWork(params) {
  return request(`/api/v2/workload/type/info`, { params });
}
export async function queryWorkDetail(params) {
  return request(`/api/v2/workload/type/auth`, { params });
}
export async function authWork(data) {
  return request(`/api/v2/workload/type/auth`, {
    method: 'POST',
    body: data,
  });
}

export async function queryMenu(params = {}) {
  return request(`/menu&version=0`, { params });
}

export async function queryProjectMenu(params) {
  return request(`/api/v2/user/project/menu/${params.ID}`);
}

export async function updateMenu(param = {}) {
  return request(`/menu/update`, {
    method: 'PUT',
    body: param,
  });
}
/**
 *
 * @param {object} param
 * @param {string} param.ParentCode 二级节点的编码
 * @param {string} param.Code 要增加的编码
 * @param {string} param.Name 要增加的名称
 * @returns
 */
export async function checkMenu(param = {}) {
  return request(`/check/menu/info`, { param });
}

export async function addMenu(param) {
  return request(`/menu/create`, {
    method: 'POST',
    body: param,
  });
}
export async function removeMenu(param) {
  return request(`/menu/delete/${param.ID}`, { method: 'DELETE' });
}

export async function addRoleRes(param) {
  return request(`/role/res`, {
    method: 'POST',
    body: param,
  });
}

export async function removeRes(params) {
  return request(`/res/delete/${params.ID}`, { method: 'DELETE' });
}

export async function addRes(params) {
  return request('/res/create', {
    method: 'POST',
    body: {
      ...params,
    },
  });
}

export async function updateRes(params = {}, currentPage, pageSize) {
  return request(`/res/update?currentPage=${currentPage}&pageSize=${pageSize}`, {
    method: 'PUT',
    body: {
      ...params,
    },
  });
}

export async function queryRole(params) {
  return request(`/role`, { params });
}

export async function queryProjectRole(params) {
  return request(`/api/v2/project/roles/get`, { params });
}

export async function removeRole(params) {
  return request(`/role/delete/${params.ID}`, { method: 'DELETE' });
}

export async function addRole(params) {
  return request('/role/create', {
    method: 'POST',
    body: {
      ...params,
    },
  });
}

export async function updateRole(params = {}, currentPage, pageSize) {
  return request(`/role/update?currentPage=${currentPage}&pageSize=${pageSize}`, {
    method: 'PUT',
    body: {
      ...params,
    },
  });
}

export async function queryUser(params) {
  return request(`/user`, { params });
}

export async function queryUserV2(params) {
  return request(`/api/v2/user`, { params });
}

export async function addUserRole(param) {
  return request(`/user/role`, {
    method: 'POST',
    body: param,
  });
}

export async function removeUser(params) {
  return request(`/user/delete/${params.ID}`, { method: 'DELETE' });
}

export async function addUser(params) {
  return request('/user/register', {
    method: 'POST',
    body: {
      ...params,
    },
  });
}

export async function updateUser(params = {}, currentPage, pageSize) {
  return request(`/user/update?currentPage=${currentPage}&pageSize=${pageSize}`, {
    method: 'PUT',
    body: {
      ...params,
    },
  });
}

export async function queryDepRole(params) {
  return request(`/api/v2/dep/role?${stringify(params)}`);
}
// 为部门设置角色
export async function bindDepRole(params) {
  return request(`/api/v2/dep/role`, {
    method: 'POST',
    body: params,
  });
}

export async function queryUserDetail(user) {
  return request(`/api/v2/user/detail/${user.ID}`);
}
// 为用户设置角色
export async function setupDepRole(data) {
  return request(`/api/v2/user/dep/role`, {
    method: 'POST',
    body: data,
  });
}

export async function queryDep(params) {
  return request(`/dep`, { params });
}
export async function queryDepV2(params) {
  return request(`/api/v2/dep`, { params });
}

export async function queryDepUser(params) {
  return request(`/api/v2/dep/user`, { params });
}

export async function removeDep(params) {
  return request(`/dep/delete/${params.ID}`, {
    method: 'DELETE',
  });
}

export async function deleteDepRole(params) {
  return request(`/api/v2/dep/role/${params.depID}/${params.roleID}`, {
    method: 'DELETE',
  });
}

export async function addDep(params) {
  return request('/dep/create', {
    method: 'POST',
    body: {
      ...params,
    },
  });
}

export async function updateDep(params = {}, currentPage, pageSize) {
  return request(`/dep/update?currentPage=${currentPage}&pageSize=${pageSize}`, {
    method: 'PUT',
    body: {
      ...params,
    },
  });
}
export async function deleteDep(data = {}) {
  return request(`/api/v2/dep/role/${data.depID}/${data.roleID}，`, {
    method: 'DELETE',
  });
}

export async function queryRoleV2(params) {
  return request(`/api/v2/project/role/get`, { params });
}
// 为项目设置roleType=1的角色
export async function setupRoleV2(params) {
  return request(`/api/v2/project/role/setup`, {
    method: 'POST',
    body: params,
  });
}
// 为项目设置roleType=2，3，4的角色
export async function setupRolesV2(params) {
  return request(`/api/v2/project/roles/setup`, {
    method: 'POST',
    body: params,
  });
}
export async function setupMenuV2(params) {
  return request(`/api/v2/project/menu/setup`, {
    method: 'POST',
    body: params,
  });
}
export async function setupBom(params) {
  return request(`/purchase/bom/excel/col`, {
    method: 'POST',
    body: params,
  });
}
export async function menuMove(params = {}) {
  return request(`/menu/move`, {
    method: 'PUT',
    body: params,
  });
}

export async function queryFeedbackList(params = {}) {
  return request(`/issue_feedback/list`, { params });
}

export async function queryBomList(params = {}) {
  return request(`/purchase/bom/excel/col`);
}

export async function updateFeedbackList(params = {}) {
  return request(`/issue_feedback/status`, {
    method: 'PUT',
    body: params,
  });
}

export async function queryWorkload(params = {}) {
  return request(`/api/v2/workload/report/permission`)
}

export async function setupWorkload(params) {
  return request(`/api/v2/workload/report/assign_permission`, {
    method: 'POST',
    body: params,
  })
}
